==> evolvotron-0.3.1.tar.gz: evolvotron/libevolvotron/dialog_about.h <==
// Source file for evolvotron
// Copyright (C) 2002,2003 Tim Day
/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*! \file 
  \brief Interface for class DialogAbout.
*/

#ifndef _dialog_about_h_
#define _dialog_about_h_

#include <qdialog.h>
#include <qvbox.h>
#include <qlabel.h>
#include <qtextedit.h>
#include <qpushbutton.h>

#include "useful.h"
#include "license.h"

//! Provides an "About" dialog box.
/*! About dialog displays author info, web addresses and license info.
 */
class DialogAbout : public QDialog
{
 private:
  Q_OBJECT

 public:
  //! Constructor.
  DialogAbout(QWidget* parent);

  //! Destructor.
  virtual ~DialogAbout()
    {}

 protected:
  //! Vertical layout.
  QVBox* _vbox;

  //! Label for name/release/author etc
  QLabel* _label;

  //! Scrolling text area for GPL.
  QTextEdit* _license;

  //! Button to close dialog.
  QPushButton* _ok;

  //! Need to pass resizes on to vbox or things just get chopped.
  virtual void resizeEvent(QResizeEvent*);
};



#endif

==> evolvotron-0.5.0.tar.gz: evolvotron/libevolvotron/dialog_about.h <==
// Source file for evolvotron
// Copyright (C) 2002,2003,2007 Tim Day
/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

/*! \file 
  \brief Interface for class DialogAbout.
*/

#ifndef _dialog_about_h_
#define _dialog_about_h_

#include <qtextedit.h>

//! Provides an "About" dialog box.
/*! About dialog displays author info, web addresses and license info.
 */
class DialogAbout : public QDialog
{
 private:
  Q_OBJECT

 public:
  //! Constructor.
  DialogAbout(QWidget* parent,int n_threads);

  //! Destructor.
  virtual ~DialogAbout()
    {}

 protected:
  //! Vertical layout.
  QVBox* _vbox;

  //! Label for name/release/author etc
  QLabel* _label;

  //! Scrolling text area for GPL.
  QTextEdit* _license;

  //! Button to close dialog.
  QPushButton* _ok;

  //! Need to pass resizes on to vbox or things just get chopped.
  virtual void resizeEvent(QResizeEvent*);
};



#endif
